Commit Diff


commit - dae613fa0e1938aee68699d7118412f82912facf
commit + f193b03845f89ae0e671e5f871fe635020cb7b48
blob - eeeea20b67e66db6ea18f137afc56636198d5de4
blob + 1c93ac41afa54d36bb8a41c39bec6058ab4d6204
--- lib/reference.c
+++ lib/reference.c
@@ -1459,7 +1459,7 @@ got_reflist_object_id_map_create(struct got_reflist_ob
 done:
 	free(id);
 	if (err) {
-		got_reflist_object_map_free(*map);
+		got_reflist_object_id_map_free(*map);
 		*map = NULL;
 	}
 	return NULL;
@@ -1487,7 +1487,7 @@ free_id_map_entry(struct got_object_id *id, void *data
 }
 
 void
-got_reflist_object_map_free(struct got_reflist_object_id_map *map)
+got_reflist_object_id_map_free(struct got_reflist_object_id_map *map)
 {
 	got_object_idset_for_each(map->idset, free_id_map_entry, NULL);
 	got_object_idset_free(map->idset);
blob - b467d0f8d577e6ecc9aa58f3c32fc5517056dbc1
blob + 08cf77f7a05719d158b1827f0afc279321117475
--- tog/tog.c
+++ tog/tog.c
@@ -145,7 +145,7 @@ static void
 tog_free_refs(void)
 {
 	if (tog_refs_idmap) {
-		got_reflist_object_map_free(tog_refs_idmap);
+		got_reflist_object_id_map_free(tog_refs_idmap);
 		tog_refs_idmap = NULL;
 	}
 	got_ref_list_free(&tog_refs);
--- include/got_reference.h
+++ include/got_reference.h
@@ -146,7 +146,7 @@ struct got_reflist_object_id_map;
 /*
  * Create and populate an object ID map for a given list of references.
  * Map entries will contain deep-copies of elements of the reflist.
  * The caller must dispose of the map with got_reflist_object_map_free().
  */
 const struct got_error *got_reflist_object_id_map_create(
     struct got_reflist_object_id_map **, struct got_reflist_head *, 
@@ -163,4 +163,4 @@ got_reflist_object_id_map_lookup(struct got_reflist_ob
     struct got_object_id *);
 
 /* Free the specified object ID map. */
-void got_reflist_object_map_free(struct got_reflist_object_id_map *);
+void got_reflist_object_id_map_free(struct got_reflist_object_id_map *);
@@ -146,7 +146,7 @@ struct got_reflist_object_id_map;
  * Create and populate an object ID map for a given list of references.
  * Map entries will contain deep-copies of elements of the reflist.
- * The caller must dispose of the map with got_reflist_object_map_free().
+ * The caller must dispose of the map with got_reflist_object_id_map_free().
  */
 const struct got_error *got_reflist_object_id_map_create(
blob - 6dba390bae34718cc3dd29ba41787375e56e54da
blob + 61bda5a52d6da70ee380d6f9af4808900d2ab1fc